.. ChemoPy documentation master file, created by
   sphinx-quickstart on Thu Sep 17 11:38:38 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ChemoPy's documentation!
==================================
.. automodule:: chemopy

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
